@@ -4,9 +4,10 @@
 #![allow(clippy::type_complexity)]
 #![allow(clippy::too_many_arguments)]
 #![allow(clippy::missing_safety_doc)]
+#![allow(clippy::manual_c_str_literals)]
 #![doc = include_str!("../README.md")]
 
-pub use ffi;
+pub use gio_sys as ffi;
 pub use glib;
 
 mod action_entry;
@@ -18,8 +19,10 @@ pub use action_entry::{ActionEntry, ActionEntryBuilder};
 pub use application::{ApplicationBusyGuard, ApplicationHoldGuard};
 mod async_initable;
 mod cancellable;
+pub use cancellable::CancelledHandlerId;
 mod cancellable_future;
 pub use crate::cancellable_future::{CancellableFuture, Cancelled};
+mod content_type;
 mod converter;
 mod credentials;
 mod data_input_stream;
@@ -28,8 +31,9 @@ mod dbus;
 pub use self::dbus::*;
 mod dbus_connection;
 pub use self::dbus_connection::{
-    ActionGroupExportId, FilterId, MenuModelExportId, RegistrationId, SignalSubscriptionId,
-    WatcherId,
+    ActionGroupExportId, DBusSignalRef, FilterId, MenuModelExportId, RegistrationBuilder,
+    RegistrationId, SignalSubscription, SignalSubscriptionId, SubscribedSignalStream, WatcherId,
+    WeakSignalSubscription,
 };
 mod dbus_message;
 mod dbus_method_invocation;
@@ -46,6 +50,8 @@ pub use crate::file_attribute_info::FileAttributeInfo;
 mod file_attribute_info_list;
 mod file_attribute_matcher;
 pub use crate::file_attribute_matcher::FileAttributematcherIter;
+mod file_attribute_value;
+pub use file_attribute_value::FileAttributeValue;
 #[cfg(unix)]
 mod file_descriptor_based;
 #[cfg(unix)]
@@ -82,8 +88,10 @@ mod simple_proxy_resolver;
 mod socket;
 pub use socket::{InputMessage, InputVector, OutputMessage, OutputVector, SocketControlMessages};
 mod socket_control_message;
+mod socket_listener;
 mod socket_msg_flags;
 pub use socket_msg_flags::SocketMsgFlags;
+mod dbus_object_manager_client;
 mod subprocess;
 mod subprocess_launcher;
 mod threaded_socket_service;
@@ -113,6 +121,7 @@ pub mod builders {
 
 pub mod functions {
     pub use super::auto::functions::*;
+    pub use super::content_type::content_type_guess;
 }
 
 pub use crate::auto::*;
@@ -145,12 +154,12 @@ pub use crate::write_output_stream::WriteOutputStream;
 mod dbus_proxy;
 mod tls_connection;
 
-#[cfg(target_family = "windows")]
+#[cfg(windows)]
 mod win32_input_stream;
-#[cfg(target_family = "windows")]
+#[cfg(windows)]
 pub use self::win32_input_stream::Win32InputStream;
 
-#[cfg(target_family = "windows")]
+#[cfg(windows)]
 mod win32_output_stream;
-#[cfg(target_family = "windows")]
+#[cfg(windows)]
 pub use self::win32_output_stream::Win32OutputStream;
